@@ -23,7 +23,7 @@ class History(object):
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
             "Accept": "application/json",
-            "User-Agent": "Python API 1.75 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.80 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
@@ -89,7 +89,7 @@ class History(object):
         )
         return json.loads(response.text)
 
-    def download(self, dataset_id, history_date, download_path=None):
+    def download(self, dataset_id, history_date, download_path=None, is_compressed=False):
         if not dataset_id:
             raise Exception('Invalid dataset_id')
 
@@ -120,19 +120,18 @@ class History(object):
                 dataset_id=dataset_id,
                 history_date=history_date,
             )
+            with open(gz_filepath, 'wb') as f:
+                shutil.copyfileobj(r.raw, f)
+            if is_compressed:
+                return gz_filepath
+
             csv_filepath = '{download_path}/{dataset_id}_{history_date}.csv'.format(
                 download_path=download_path,
                 dataset_id=dataset_id,
                 history_date=history_date,
             )
-
-            with open(gz_filepath, 'wb') as f:
-                shutil.copyfileobj(r.raw, f)
-            
             with gzip.open(gz_filepath, 'rb') as f_in:
                 with open(csv_filepath, 'wb') as f_out:
                     shutil.copyfileobj(f_in, f_out)
-
             os.remove(gz_filepath)
-
             return csv_filepath
