@@ -24,7 +24,7 @@ class Query(object):
             "Accept": "application/json",
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "User-Agent": "Python API 1.75 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.80 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
@@ -36,7 +36,15 @@ class Query(object):
         self._sorts = []
         self._start = 1
         self._limit = 100000
-    
+
+    def _raise_exception_from_response(self, response):
+        try:
+            message = json.loads(response.text).get("message")
+        except Exception as e:
+            raise Exception(response.text)
+        else:
+            raise Exception(message)
+
     def _requests(self, method, url, headers={}, data={}, json={}, params={}):
         if method not in ['post', 'get', 'head']:
             raise Exception('Not allowed method')
@@ -65,6 +73,7 @@ class Query(object):
             raise Exception(message)
         self._token = json.loads(response.text)['auth_token']
 
+
     @property
     def _query(self):
         query = {}
@@ -149,8 +158,7 @@ class Query(object):
             headers=self._headers
         )
         if response.status_code != self.OK:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
         return json.loads(response.text).get('datasets', [])
 
     # Return dataset metadata
@@ -167,8 +175,7 @@ class Query(object):
             headers=self._headers
         )
         if response.status_code != self.OK:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
 
         result = json.loads(response.text)
         return {
@@ -197,8 +204,7 @@ class Query(object):
             }
         )
         if response.status_code != self.OK:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
         return json.loads(response.text).get('datasets', [])
 
     # Return ticker list from search term
@@ -223,8 +229,7 @@ class Query(object):
             params={"query": query}
         )
         if response.status_code != self.OK:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
 
         return json.loads(response.text).get('queries', {}).get(query, [])
 
@@ -241,16 +246,16 @@ class Query(object):
                 dataset_id=dataset_id
             ),
             headers=self._headers,
-            json=self._query
+            json=self._query,
         )
         if response.status_code != self.CREATED:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
         result = json.loads(response.text)
         query_id = result.get('id')
 
         # 2. HEAD
-        while True:
+        is_created = False
+        for index in range(60):
             response = self._requests(
                 method='head',
                 url='{base_url}/datasets/{dataset_id}/query/{query_id}'.format(
@@ -264,13 +269,16 @@ class Query(object):
                 )
             )
             if response.status_code == self.OK:
+                is_created = True
                 break
             elif response.status_code == self.ACCEPTED:
                 time.sleep(1)
                 continue
             else:
-                message = json.loads(response.text).get("message")
-                raise Exception(message)
+                self._raise_exception_from_response(response)
+
+        if not is_created:
+            raise Exception("Data still being fetched. Please retry it")
 
         # 3. GET
         if start and limit:
@@ -280,7 +288,6 @@ class Query(object):
             raise Exception('Start offset is less than 1')
         if self._limit < 1:
             raise Exception('Limit offset is less than 1')
-
         response = self._requests(
             method='get',
             url='{base_url}/datasets/{dataset_id}/query/{query_id}'.format(
@@ -298,6 +305,5 @@ class Query(object):
             }
         )
         if response.status_code != self.OK:
-            message = json.loads(response.text).get("message")
-            raise Exception(message)
+            self._raise_exception_from_response(response)
         return json.loads(response.text)
